# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tendermint/state/types.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from tendermint.abci import types_pb2 as tendermint_dot_abci_dot_types__pb2
from tendermint.types import types_pb2 as tendermint_dot_types_dot_types__pb2
from tendermint.types import validator_pb2 as tendermint_dot_types_dot_validator__pb2
from tendermint.types import params_pb2 as tendermint_dot_types_dot_params__pb2
from tendermint.version import types_pb2 as tendermint_dot_version_dot_types__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1ctendermint/state/types.proto\x12\x10tendermint.state\x1a\x14gogoproto/gogo.proto\x1a\x1btendermint/abci/types.proto\x1a\x1ctendermint/types/types.proto\x1a tendermint/types/validator.proto\x1a\x1dtendermint/types/params.proto\x1a\x1etendermint/version/types.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xb8\x01\n\rABCIResponses\x12\x37\n\x0b\x64\x65liver_txs\x18\x01 \x03(\x0b\x32\".tendermint.abci.ResponseDeliverTx\x12\x34\n\tend_block\x18\x02 \x01(\x0b\x32!.tendermint.abci.ResponseEndBlock\x12\x38\n\x0b\x62\x65gin_block\x18\x03 \x01(\x0b\x32#.tendermint.abci.ResponseBeginBlock\"d\n\x0eValidatorsInfo\x12\x35\n\rvalidator_set\x18\x01 \x01(\x0b\x32\x1e.tendermint.types.ValidatorSet\x12\x1b\n\x13last_height_changed\x18\x02 \x01(\x03\"u\n\x13\x43onsensusParamsInfo\x12\x41\n\x10\x63onsensus_params\x18\x01 \x01(\x0b\x32!.tendermint.types.ConsensusParamsB\x04\xc8\xde\x1f\x00\x12\x1b\n\x13last_height_changed\x18\x02 \x01(\x03\"S\n\x07Version\x12\x36\n\tconsensus\x18\x01 \x01(\x0b\x32\x1d.tendermint.version.ConsensusB\x04\xc8\xde\x1f\x00\x12\x10\n\x08software\x18\x02 \x01(\t\"\xfd\x04\n\x05State\x12\x30\n\x07version\x18\x01 \x01(\x0b\x32\x19.tendermint.state.VersionB\x04\xc8\xde\x1f\x00\x12\x1d\n\x08\x63hain_id\x18\x02 \x01(\tB\x0b\xe2\xde\x1f\x07\x43hainID\x12\x16\n\x0einitial_height\x18\x0e \x01(\x03\x12\x19\n\x11last_block_height\x18\x03 \x01(\x03\x12\x45\n\rlast_block_id\x18\x04 \x01(\x0b\x32\x19.tendermint.types.BlockIDB\x13\xc8\xde\x1f\x00\xe2\xde\x1f\x0bLastBlockID\x12=\n\x0flast_block_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\x12\x37\n\x0fnext_validators\x18\x06 \x01(\x0b\x32\x1e.tendermint.types.ValidatorSet\x12\x32\n\nvalidators\x18\x07 \x01(\x0b\x32\x1e.tendermint.types.ValidatorSet\x12\x37\n\x0flast_validators\x18\x08 \x01(\x0b\x32\x1e.tendermint.types.ValidatorSet\x12&\n\x1elast_height_validators_changed\x18\t \x01(\x03\x12\x41\n\x10\x63onsensus_params\x18\n \x01(\x0b\x32!.tendermint.types.ConsensusParamsB\x04\xc8\xde\x1f\x00\x12,\n$last_height_consensus_params_changed\x18\x0b \x01(\x03\x12\x19\n\x11last_results_hash\x18\x0c \x01(\x0c\x12\x10\n\x08\x61pp_hash\x18\r \x01(\x0c\x42\x39Z7github.com/tendermint/tendermint/proto/tendermint/stateb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tendermint.state.types_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z7github.com/tendermint/tendermint/proto/tendermint/state'
  _CONSENSUSPARAMSINFO.fields_by_name['consensus_params']._options = None
  _CONSENSUSPARAMSINFO.fields_by_name['consensus_params']._serialized_options = b'\310\336\037\000'
  _VERSION.fields_by_name['consensus']._options = None
  _VERSION.fields_by_name['consensus']._serialized_options = b'\310\336\037\000'
  _STATE.fields_by_name['version']._options = None
  _STATE.fields_by_name['version']._serialized_options = b'\310\336\037\000'
  _STATE.fields_by_name['chain_id']._options = None
  _STATE.fields_by_name['chain_id']._serialized_options = b'\342\336\037\007ChainID'
  _STATE.fields_by_name['last_block_id']._options = None
  _STATE.fields_by_name['last_block_id']._serialized_options = b'\310\336\037\000\342\336\037\013LastBlockID'
  _STATE.fields_by_name['last_block_time']._options = None
  _STATE.fields_by_name['last_block_time']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _STATE.fields_by_name['consensus_params']._options = None
  _STATE.fields_by_name['consensus_params']._serialized_options = b'\310\336\037\000'
  _ABCIRESPONSES._serialized_start=262
  _ABCIRESPONSES._serialized_end=446
  _VALIDATORSINFO._serialized_start=448
  _VALIDATORSINFO._serialized_end=548
  _CONSENSUSPARAMSINFO._serialized_start=550
  _CONSENSUSPARAMSINFO._serialized_end=667
  _VERSION._serialized_start=669
  _VERSION._serialized_end=752
  _STATE._serialized_start=755
  _STATE._serialized_end=1392
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: exchange/injective_insurance_rpc.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&exchange/injective_insurance_rpc.proto\x12\x17injective_insurance_rpc\"\x0e\n\x0c\x46undsRequest\"F\n\rFundsResponse\x12\x35\n\x05\x66unds\x18\x01 \x03(\x0b\x32&.injective_insurance_rpc.InsuranceFund\"\xcb\x02\n\rInsuranceFund\x12\x15\n\rmarket_ticker\x18\x01 \x01(\t\x12\x11\n\tmarket_id\x18\x02 \x01(\t\x12\x15\n\rdeposit_denom\x18\x03 \x01(\t\x12\x18\n\x10pool_token_denom\x18\x04 \x01(\t\x12)\n!redemption_notice_period_duration\x18\x05 \x01(\x12\x12\x0f\n\x07\x62\x61lance\x18\x06 \x01(\t\x12\x13\n\x0btotal_share\x18\x07 \x01(\t\x12\x13\n\x0boracle_base\x18\x08 \x01(\t\x12\x14\n\x0coracle_quote\x18\t \x01(\t\x12\x13\n\x0boracle_type\x18\n \x01(\t\x12\x0e\n\x06\x65xpiry\x18\x0b \x01(\x12\x12>\n\x12\x64\x65posit_token_meta\x18\x0c \x01(\x0b\x32\".injective_insurance_rpc.TokenMeta\"n\n\tTokenMeta\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\t\x12\x0e\n\x06symbol\x18\x03 \x01(\t\x12\x0c\n\x04logo\x18\x04 \x01(\t\x12\x10\n\x08\x64\x65\x63imals\x18\x05 \x01(\x11\x12\x12\n\nupdated_at\x18\x06 \x01(\x12\"P\n\x12RedemptionsRequest\x12\x10\n\x08redeemer\x18\x01 \x01(\t\x12\x18\n\x10redemption_denom\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\t\"`\n\x13RedemptionsResponse\x12I\n\x14redemption_schedules\x18\x01 \x03(\x0b\x32+.injective_insurance_rpc.RedemptionSchedule\"\x84\x02\n\x12RedemptionSchedule\x12\x15\n\rredemption_id\x18\x01 \x01(\x04\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x10\n\x08redeemer\x18\x03 \x01(\t\x12!\n\x19\x63laimable_redemption_time\x18\x04 \x01(\x12\x12\x19\n\x11redemption_amount\x18\x05 \x01(\t\x12\x18\n\x10redemption_denom\x18\x06 \x01(\t\x12\x14\n\x0crequested_at\x18\x07 \x01(\x12\x12\x18\n\x10\x64isbursed_amount\x18\x08 \x01(\t\x12\x17\n\x0f\x64isbursed_denom\x18\t \x01(\t\x12\x14\n\x0c\x64isbursed_at\x18\n \x01(\x12\x32\xd9\x01\n\x15InjectiveInsuranceRPC\x12V\n\x05\x46unds\x12%.injective_insurance_rpc.FundsRequest\x1a&.injective_insurance_rpc.FundsResponse\x12h\n\x0bRedemptions\x12+.injective_insurance_rpc.RedemptionsRequest\x1a,.injective_insurance_rpc.RedemptionsResponseB\x1cZ\x1a/injective_insurance_rpcpbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'exchange.injective_insurance_rpc_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\032/injective_insurance_rpcpb'
  _FUNDSREQUEST._serialized_start=67
  _FUNDSREQUEST._serialized_end=81
  _FUNDSRESPONSE._serialized_start=83
  _FUNDSRESPONSE._serialized_end=153
  _INSURANCEFUND._serialized_start=156
  _INSURANCEFUND._serialized_end=487
  _TOKENMETA._serialized_start=489
  _TOKENMETA._serialized_end=599
  _REDEMPTIONSREQUEST._serialized_start=601
  _REDEMPTIONSREQUEST._serialized_end=681
  _REDEMPTIONSRESPONSE._serialized_start=683
  _REDEMPTIONSRESPONSE._serialized_end=779
  _REDEMPTIONSCHEDULE._serialized_start=782
  _REDEMPTIONSCHEDULE._serialized_end=1042
  _INJECTIVEINSURANCERPC._serialized_start=1045
  _INJECTIVEINSURANCERPC._serialized_end=1262
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: exchange/injective_portfolio_rpc.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&exchange/injective_portfolio_rpc.proto\x12\x17injective_portfolio_rpc\"2\n\x17\x41\x63\x63ountPortfolioRequest\x12\x17\n\x0f\x61\x63\x63ount_address\x18\x01 \x01(\t\"Q\n\x18\x41\x63\x63ountPortfolioResponse\x12\x35\n\tportfolio\x18\x01 \x01(\x0b\x32\".injective_portfolio_rpc.Portfolio\"\xe6\x01\n\tPortfolio\x12\x17\n\x0f\x61\x63\x63ount_address\x18\x01 \x01(\t\x12\x34\n\rbank_balances\x18\x02 \x03(\x0b\x32\x1d.injective_portfolio_rpc.Coin\x12\x41\n\x0bsubaccounts\x18\x03 \x03(\x0b\x32,.injective_portfolio_rpc.SubaccountBalanceV2\x12G\n\x13positions_with_upnl\x18\x04 \x03(\x0b\x32*.injective_portfolio_rpc.PositionsWithUPNL\"%\n\x04\x43oin\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\x12\x0e\n\x06\x61mount\x18\x02 \x01(\t\"x\n\x13SubaccountBalanceV2\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\r\n\x05\x64\x65nom\x18\x02 \x01(\t\x12;\n\x07\x64\x65posit\x18\x03 \x01(\x0b\x32*.injective_portfolio_rpc.SubaccountDeposit\"E\n\x11SubaccountDeposit\x12\x15\n\rtotal_balance\x18\x01 \x01(\t\x12\x19\n\x11\x61vailable_balance\x18\x02 \x01(\t\"j\n\x11PositionsWithUPNL\x12=\n\x08position\x18\x01 \x01(\x0b\x32+.injective_portfolio_rpc.DerivativePosition\x12\x16\n\x0eunrealized_pnl\x18\x02 \x01(\t\"\x97\x02\n\x12\x44\x65rivativePosition\x12\x0e\n\x06ticker\x18\x01 \x01(\t\x12\x11\n\tmarket_id\x18\x02 \x01(\t\x12\x15\n\rsubaccount_id\x18\x03 \x01(\t\x12\x11\n\tdirection\x18\x04 \x01(\t\x12\x10\n\x08quantity\x18\x05 \x01(\t\x12\x13\n\x0b\x65ntry_price\x18\x06 \x01(\t\x12\x0e\n\x06margin\x18\x07 \x01(\t\x12\x19\n\x11liquidation_price\x18\x08 \x01(\t\x12\x12\n\nmark_price\x18\t \x01(\t\x12&\n\x1e\x61ggregate_reduce_only_quantity\x18\x0b \x01(\t\x12\x12\n\nupdated_at\x18\x0c \x01(\x12\x12\x12\n\ncreated_at\x18\r \x01(\x12\"]\n\x1dStreamAccountPortfolioRequest\x12\x17\n\x0f\x61\x63\x63ount_address\x18\x01 \x01(\t\x12\x15\n\rsubaccount_id\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\"d\n\x1eStreamAccountPortfolioResponse\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\r\n\x05\x64\x65nom\x18\x02 \x01(\t\x12\x0e\n\x06\x61mount\x18\x03 \x01(\t\x12\x15\n\rsubaccount_id\x18\x04 \x01(\t2\x9e\x02\n\x15InjectivePortfolioRPC\x12w\n\x10\x41\x63\x63ountPortfolio\x12\x30.injective_portfolio_rpc.AccountPortfolioRequest\x1a\x31.injective_portfolio_rpc.AccountPortfolioResponse\x12\x8b\x01\n\x16StreamAccountPortfolio\x12\x36.injective_portfolio_rpc.StreamAccountPortfolioRequest\x1a\x37.injective_portfolio_rpc.StreamAccountPortfolioResponse0\x01\x42\x1cZ\x1a/injective_portfolio_rpcpbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'exchange.injective_portfolio_rpc_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\032/injective_portfolio_rpcpb'
  _ACCOUNTPORTFOLIOREQUEST._serialized_start=67
  _ACCOUNTPORTFOLIOREQUEST._serialized_end=117
  _ACCOUNTPORTFOLIORESPONSE._serialized_start=119
  _ACCOUNTPORTFOLIORESPONSE._serialized_end=200
  _PORTFOLIO._serialized_start=203
  _PORTFOLIO._serialized_end=433
  _COIN._serialized_start=435
  _COIN._serialized_end=472
  _SUBACCOUNTBALANCEV2._serialized_start=474
  _SUBACCOUNTBALANCEV2._serialized_end=594
  _SUBACCOUNTDEPOSIT._serialized_start=596
  _SUBACCOUNTDEPOSIT._serialized_end=665
  _POSITIONSWITHUPNL._serialized_start=667
  _POSITIONSWITHUPNL._serialized_end=773
  _DERIVATIVEPOSITION._serialized_start=776
  _DERIVATIVEPOSITION._serialized_end=1055
  _STREAMACCOUNTPORTFOLIOREQUEST._serialized_start=1057
  _STREAMACCOUNTPORTFOLIOREQUEST._serialized_end=1150
  _STREAMACCOUNTPORTFOLIORESPONSE._serialized_start=1152
  _STREAMACCOUNTPORTFOLIORESPONSE._serialized_end=1252
  _INJECTIVEPORTFOLIORPC._serialized_start=1255
  _INJECTIVEPORTFOLIORPC._serialized_end=1541
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmwasm/wasm/v1/ibc.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x63osmwasm/wasm/v1/ibc.proto\x12\x10\x63osmwasm.wasm.v1\x1a\x14gogoproto/gogo.proto\"\xb2\x01\n\nMsgIBCSend\x12*\n\x07\x63hannel\x18\x02 \x01(\tB\x19\xf2\xde\x1f\x15yaml:\"source_channel\"\x12\x31\n\x0etimeout_height\x18\x04 \x01(\x04\x42\x19\xf2\xde\x1f\x15yaml:\"timeout_height\"\x12\x37\n\x11timeout_timestamp\x18\x05 \x01(\x04\x42\x1c\xf2\xde\x1f\x18yaml:\"timeout_timestamp\"\x12\x0c\n\x04\x64\x61ta\x18\x06 \x01(\x0c\"@\n\x12MsgIBCCloseChannel\x12*\n\x07\x63hannel\x18\x02 \x01(\tB\x19\xf2\xde\x1f\x15yaml:\"source_channel\"B,Z&github.com/CosmWasm/wasmd/x/wasm/types\xc8\xe1\x1e\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmwasm.wasm.v1.ibc_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z&github.com/CosmWasm/wasmd/x/wasm/types\310\341\036\000'
  _MSGIBCSEND.fields_by_name['channel']._options = None
  _MSGIBCSEND.fields_by_name['channel']._serialized_options = b'\362\336\037\025yaml:\"source_channel\"'
  _MSGIBCSEND.fields_by_name['timeout_height']._options = None
  _MSGIBCSEND.fields_by_name['timeout_height']._serialized_options = b'\362\336\037\025yaml:\"timeout_height\"'
  _MSGIBCSEND.fields_by_name['timeout_timestamp']._options = None
  _MSGIBCSEND.fields_by_name['timeout_timestamp']._serialized_options = b'\362\336\037\030yaml:\"timeout_timestamp\"'
  _MSGIBCCLOSECHANNEL.fields_by_name['channel']._options = None
  _MSGIBCCLOSECHANNEL.fields_by_name['channel']._serialized_options = b'\362\336\037\025yaml:\"source_channel\"'
  _MSGIBCSEND._serialized_start=71
  _MSGIBCSEND._serialized_end=249
  _MSGIBCCLOSECHANNEL._serialized_start=251
  _MSGIBCCLOSECHANNEL._serialized_end=315
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/wasmx/v1/proposal.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmwasm.wasm.v1 import proposal_pb2 as cosmwasm_dot_wasm_dot_v1_dot_proposal__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!injective/wasmx/v1/proposal.proto\x12\x12injective.wasmx.v1\x1a\x14gogoproto/gogo.proto\x1a\x1f\x63osmwasm/wasm/v1/proposal.proto\"\xb1\x01\n#ContractRegistrationRequestProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\\\n\x1d\x63ontract_registration_request\x18\x03 \x01(\x0b\x32/.injective.wasmx.v1.ContractRegistrationRequestB\x04\xc8\xde\x1f\x00:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\xb7\x01\n(BatchContractRegistrationRequestProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12]\n\x1e\x63ontract_registration_requests\x18\x03 \x03(\x0b\x32/.injective.wasmx.v1.ContractRegistrationRequestB\x04\xc8\xde\x1f\x00:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"l\n#BatchContractDeregistrationProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x17\n\tcontracts\x18\x03 \x03(\tB\x04\xc8\xde\x1f\x00:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\xc0\x01\n\x1b\x43ontractRegistrationRequest\x12\x18\n\x10\x63ontract_address\x18\x01 \x01(\t\x12\x11\n\tgas_limit\x18\x02 \x01(\x04\x12\x11\n\tgas_price\x18\x03 \x01(\x04\x12\x1b\n\x13should_pin_contract\x18\x04 \x01(\x08\x12\x1c\n\x14is_migration_allowed\x18\x05 \x01(\x08\x12\x0f\n\x07\x63ode_id\x18\x06 \x01(\x04\x12\x15\n\radmin_address\x18\x07 \x01(\t\"\x84\x01\n\x16\x42\x61tchStoreCodeProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12<\n\tproposals\x18\x03 \x03(\x0b\x32#.cosmwasm.wasm.v1.StoreCodeProposalB\x04\xc8\xde\x1f\x00:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\x42MZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/wasmx/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.wasmx.v1.proposal_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/wasmx/types'
  _CONTRACTREGISTRATIONREQUESTPROPOSAL.fields_by_name['contract_registration_request']._options = None
  _CONTRACTREGISTRATIONREQUESTPROPOSAL.fields_by_name['contract_registration_request']._serialized_options = b'\310\336\037\000'
  _CONTRACTREGISTRATIONREQUESTPROPOSAL._options = None
  _CONTRACTREGISTRATIONREQUESTPROPOSAL._serialized_options = b'\350\240\037\000\210\240\037\000'
  _BATCHCONTRACTREGISTRATIONREQUESTPROPOSAL.fields_by_name['contract_registration_requests']._options = None
  _BATCHCONTRACTREGISTRATIONREQUESTPROPOSAL.fields_by_name['contract_registration_requests']._serialized_options = b'\310\336\037\000'
  _BATCHCONTRACTREGISTRATIONREQUESTPROPOSAL._options = None
  _BATCHCONTRACTREGISTRATIONREQUESTPROPOSAL._serialized_options = b'\350\240\037\000\210\240\037\000'
  _BATCHCONTRACTDEREGISTRATIONPROPOSAL.fields_by_name['contracts']._options = None
  _BATCHCONTRACTDEREGISTRATIONPROPOSAL.fields_by_name['contracts']._serialized_options = b'\310\336\037\000'
  _BATCHCONTRACTDEREGISTRATIONPROPOSAL._options = None
  _BATCHCONTRACTDEREGISTRATIONPROPOSAL._serialized_options = b'\350\240\037\000\210\240\037\000'
  _BATCHSTORECODEPROPOSAL.fields_by_name['proposals']._options = None
  _BATCHSTORECODEPROPOSAL.fields_by_name['proposals']._serialized_options = b'\310\336\037\000'
  _BATCHSTORECODEPROPOSAL._options = None
  _BATCHSTORECODEPROPOSAL._serialized_options = b'\350\240\037\000\210\240\037\000'
  _CONTRACTREGISTRATIONREQUESTPROPOSAL._serialized_start=113
  _CONTRACTREGISTRATIONREQUESTPROPOSAL._serialized_end=290
  _BATCHCONTRACTREGISTRATIONREQUESTPROPOSAL._serialized_start=293
  _BATCHCONTRACTREGISTRATIONREQUESTPROPOSAL._serialized_end=476
  _BATCHCONTRACTDEREGISTRATIONPROPOSAL._serialized_start=478
  _BATCHCONTRACTDEREGISTRATIONPROPOSAL._serialized_end=586
  _CONTRACTREGISTRATIONREQUEST._serialized_start=589
  _CONTRACTREGISTRATIONREQUEST._serialized_end=781
  _BATCHSTORECODEPROPOSAL._serialized_start=784
  _BATCHSTORECODEPROPOSAL._serialized_end=916
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/core/channel/v1/tx.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from ibc.core.client.v1 import client_pb2 as ibc_dot_core_dot_client_dot_v1_dot_client__pb2
from ibc.core.channel.v1 import channel_pb2 as ibc_dot_core_dot_channel_dot_v1_dot_channel__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cibc/core/channel/v1/tx.proto\x12\x13ibc.core.channel.v1\x1a\x14gogoproto/gogo.proto\x1a\x1fibc/core/client/v1/client.proto\x1a!ibc/core/channel/v1/channel.proto\"\x88\x01\n\x12MsgChannelOpenInit\x12#\n\x07port_id\x18\x01 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:\"port_id\"\x12\x33\n\x07\x63hannel\x18\x02 \x01(\x0b\x32\x1c.ibc.core.channel.v1.ChannelB\x04\xc8\xde\x1f\x00\x12\x0e\n\x06signer\x18\x03 \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x1c\n\x1aMsgChannelOpenInitResponse\"\xfd\x02\n\x11MsgChannelOpenTry\x12#\n\x07port_id\x18\x01 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:\"port_id\"\x12;\n\x13previous_channel_id\x18\x02 \x01(\tB\x1e\xf2\xde\x1f\x1ayaml:\"previous_channel_id\"\x12\x33\n\x07\x63hannel\x18\x03 \x01(\x0b\x32\x1c.ibc.core.channel.v1.ChannelB\x04\xc8\xde\x1f\x00\x12=\n\x14\x63ounterparty_version\x18\x04 \x01(\tB\x1f\xf2\xde\x1f\x1byaml:\"counterparty_version\"\x12)\n\nproof_init\x18\x05 \x01(\x0c\x42\x15\xf2\xde\x1f\x11yaml:\"proof_init\"\x12M\n\x0cproof_height\x18\x06 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x1b\xf2\xde\x1f\x13yaml:\"proof_height\"\xc8\xde\x1f\x00\x12\x0e\n\x06signer\x18\x07 \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x1b\n\x19MsgChannelOpenTryResponse\"\xf9\x02\n\x11MsgChannelOpenAck\x12#\n\x07port_id\x18\x01 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:\"port_id\"\x12)\n\nchannel_id\x18\x02 \x01(\tB\x15\xf2\xde\x1f\x11yaml:\"channel_id\"\x12\x43\n\x17\x63ounterparty_channel_id\x18\x03 \x01(\tB\"\xf2\xde\x1f\x1eyaml:\"counterparty_channel_id\"\x12=\n\x14\x63ounterparty_version\x18\x04 \x01(\tB\x1f\xf2\xde\x1f\x1byaml:\"counterparty_version\"\x12\'\n\tproof_try\x18\x05 \x01(\x0c\x42\x14\xf2\xde\x1f\x10yaml:\"proof_try\"\x12M\n\x0cproof_height\x18\x06 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x1b\xf2\xde\x1f\x13yaml:\"proof_height\"\xc8\xde\x1f\x00\x12\x0e\n\x06signer\x18\x07 \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x1b\n\x19MsgChannelOpenAckResponse\"\xf9\x01\n\x15MsgChannelOpenConfirm\x12#\n\x07port_id\x18\x01 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:\"port_id\"\x12)\n\nchannel_id\x18\x02 \x01(\tB\x15\xf2\xde\x1f\x11yaml:\"channel_id\"\x12\'\n\tproof_ack\x18\x03 \x01(\x0c\x42\x14\xf2\xde\x1f\x10yaml:\"proof_ack\"\x12M\n\x0cproof_height\x18\x04 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x1b\xf2\xde\x1f\x13yaml:\"proof_height\"\xc8\xde\x1f\x00\x12\x0e\n\x06signer\x18\x05 \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x1f\n\x1dMsgChannelOpenConfirmResponse\"\x7f\n\x13MsgChannelCloseInit\x12#\n\x07port_id\x18\x01 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:\"port_id\"\x12)\n\nchannel_id\x18\x02 \x01(\tB\x15\xf2\xde\x1f\x11yaml:\"channel_id\"\x12\x0e\n\x06signer\x18\x03 \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x1d\n\x1bMsgChannelCloseInitResponse\"\xfc\x01\n\x16MsgChannelCloseConfirm\x12#\n\x07port_id\x18\x01 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:\"port_id\"\x12)\n\nchannel_id\x18\x02 \x01(\tB\x15\xf2\xde\x1f\x11yaml:\"channel_id\"\x12)\n\nproof_init\x18\x03 \x01(\x0c\x42\x15\xf2\xde\x1f\x11yaml:\"proof_init\"\x12M\n\x0cproof_height\x18\x04 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x1b\xf2\xde\x1f\x13yaml:\"proof_height\"\xc8\xde\x1f\x00\x12\x0e\n\x06signer\x18\x05 \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\" \n\x1eMsgChannelCloseConfirmResponse\"\xe2\x01\n\rMsgRecvPacket\x12\x31\n\x06packet\x18\x01 \x01(\x0b\x32\x1b.ibc.core.channel.v1.PacketB\x04\xc8\xde\x1f\x00\x12\x35\n\x10proof_commitment\x18\x02 \x01(\x0c\x42\x1b\xf2\xde\x1f\x17yaml:\"proof_commitment\"\x12M\n\x0cproof_height\x18\x03 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x1b\xf2\xde\x1f\x13yaml:\"proof_height\"\xc8\xde\x1f\x00\x12\x0e\n\x06signer\x18\x04 \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x17\n\x15MsgRecvPacketResponse\"\x9a\x02\n\nMsgTimeout\x12\x31\n\x06packet\x18\x01 \x01(\x0b\x32\x1b.ibc.core.channel.v1.PacketB\x04\xc8\xde\x1f\x00\x12\x35\n\x10proof_unreceived\x18\x02 \x01(\x0c\x42\x1b\xf2\xde\x1f\x17yaml:\"proof_unreceived\"\x12M\n\x0cproof_height\x18\x03 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x1b\xf2\xde\x1f\x13yaml:\"proof_height\"\xc8\xde\x1f\x00\x12\x39\n\x12next_sequence_recv\x18\x04 \x01(\x04\x42\x1d\xf2\xde\x1f\x19yaml:\"next_sequence_recv\"\x12\x0e\n\x06signer\x18\x05 \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x14\n\x12MsgTimeoutResponse\"\xce\x02\n\x11MsgTimeoutOnClose\x12\x31\n\x06packet\x18\x01 \x01(\x0b\x32\x1b.ibc.core.channel.v1.PacketB\x04\xc8\xde\x1f\x00\x12\x35\n\x10proof_unreceived\x18\x02 \x01(\x0c\x42\x1b\xf2\xde\x1f\x17yaml:\"proof_unreceived\"\x12+\n\x0bproof_close\x18\x03 \x01(\x0c\x42\x16\xf2\xde\x1f\x12yaml:\"proof_close\"\x12M\n\x0cproof_height\x18\x04 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x1b\xf2\xde\x1f\x13yaml:\"proof_height\"\xc8\xde\x1f\x00\x12\x39\n\x12next_sequence_recv\x18\x05 \x01(\x04\x42\x1d\xf2\xde\x1f\x19yaml:\"next_sequence_recv\"\x12\x0e\n\x06signer\x18\x06 \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x1b\n\x19MsgTimeoutOnCloseResponse\"\xf6\x01\n\x12MsgAcknowledgement\x12\x31\n\x06packet\x18\x01 \x01(\x0b\x32\x1b.ibc.core.channel.v1.PacketB\x04\xc8\xde\x1f\x00\x12\x17\n\x0f\x61\x63knowledgement\x18\x02 \x01(\x0c\x12+\n\x0bproof_acked\x18\x03 \x01(\x0c\x42\x16\xf2\xde\x1f\x12yaml:\"proof_acked\"\x12M\n\x0cproof_height\x18\x04 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x1b\xf2\xde\x1f\x13yaml:\"proof_height\"\xc8\xde\x1f\x00\x12\x0e\n\x06signer\x18\x05 \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x1c\n\x1aMsgAcknowledgementResponse2\xaf\x08\n\x03Msg\x12k\n\x0f\x43hannelOpenInit\x12\'.ibc.core.channel.v1.MsgChannelOpenInit\x1a/.ibc.core.channel.v1.MsgChannelOpenInitResponse\x12h\n\x0e\x43hannelOpenTry\x12&.ibc.core.channel.v1.MsgChannelOpenTry\x1a..ibc.core.channel.v1.MsgChannelOpenTryResponse\x12h\n\x0e\x43hannelOpenAck\x12&.ibc.core.channel.v1.MsgChannelOpenAck\x1a..ibc.core.channel.v1.MsgChannelOpenAckResponse\x12t\n\x12\x43hannelOpenConfirm\x12*.ibc.core.channel.v1.MsgChannelOpenConfirm\x1a\x32.ibc.core.channel.v1.MsgChannelOpenConfirmResponse\x12n\n\x10\x43hannelCloseInit\x12(.ibc.core.channel.v1.MsgChannelCloseInit\x1a\x30.ibc.core.channel.v1.MsgChannelCloseInitResponse\x12w\n\x13\x43hannelCloseConfirm\x12+.ibc.core.channel.v1.MsgChannelCloseConfirm\x1a\x33.ibc.core.channel.v1.MsgChannelCloseConfirmResponse\x12\\\n\nRecvPacket\x12\".ibc.core.channel.v1.MsgRecvPacket\x1a*.ibc.core.channel.v1.MsgRecvPacketResponse\x12S\n\x07Timeout\x12\x1f.ibc.core.channel.v1.MsgTimeout\x1a\'.ibc.core.channel.v1.MsgTimeoutResponse\x12h\n\x0eTimeoutOnClose\x12&.ibc.core.channel.v1.MsgTimeoutOnClose\x1a..ibc.core.channel.v1.MsgTimeoutOnCloseResponse\x12k\n\x0f\x41\x63knowledgement\x12\'.ibc.core.channel.v1.MsgAcknowledgement\x1a/.ibc.core.channel.v1.MsgAcknowledgementResponseB;Z9github.com/cosmos/ibc-go/v2/modules/core/04-channel/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.core.channel.v1.tx_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z9github.com/cosmos/ibc-go/v2/modules/core/04-channel/types'
  _MSGCHANNELOPENINIT.fields_by_name['port_id']._options = None
  _MSGCHANNELOPENINIT.fields_by_name['port_id']._serialized_options = b'\362\336\037\016yaml:\"port_id\"'
  _MSGCHANNELOPENINIT.fields_by_name['channel']._options = None
  _MSGCHANNELOPENINIT.fields_by_name['channel']._serialized_options = b'\310\336\037\000'
  _MSGCHANNELOPENINIT._options = None
  _MSGCHANNELOPENINIT._serialized_options = b'\350\240\037\000\210\240\037\000'
  _MSGCHANNELOPENTRY.fields_by_name['port_id']._options = None
  _MSGCHANNELOPENTRY.fields_by_name['port_id']._serialized_options = b'\362\336\037\016yaml:\"port_id\"'
  _MSGCHANNELOPENTRY.fields_by_name['previous_channel_id']._options = None
  _MSGCHANNELOPENTRY.fields_by_name['previous_channel_id']._serialized_options = b'\362\336\037\032yaml:\"previous_channel_id\"'
  _MSGCHANNELOPENTRY.fields_by_name['channel']._options = None
  _MSGCHANNELOPENTRY.fields_by_name['channel']._serialized_options = b'\310\336\037\000'
  _MSGCHANNELOPENTRY.fields_by_name['counterparty_version']._options = None
  _MSGCHANNELOPENTRY.fields_by_name['counterparty_version']._serialized_options = b'\362\336\037\033yaml:\"counterparty_version\"'
  _MSGCHANNELOPENTRY.fields_by_name['proof_init']._options = None
  _MSGCHANNELOPENTRY.fields_by_name['proof_init']._serialized_options = b'\362\336\037\021yaml:\"proof_init\"'
  _MSGCHANNELOPENTRY.fields_by_name['proof_height']._options = None
  _MSGCHANNELOPENTRY.fields_by_name['proof_height']._serialized_options = b'\362\336\037\023yaml:\"proof_height\"\310\336\037\000'
  _MSGCHANNELOPENTRY._options = None
  _MSGCHANNELOPENTRY._serialized_options = b'\350\240\037\000\210\240\037\000'
  _MSGCHANNELOPENACK.fields_by_name['port_id']._options = None
  _MSGCHANNELOPENACK.fields_by_name['port_id']._serialized_options = b'\362\336\037\016yaml:\"port_id\"'
  _MSGCHANNELOPENACK.fields_by_name['channel_id']._options = None
  _MSGCHANNELOPENACK.fields_by_name['channel_id']._serialized_options = b'\362\336\037\021yaml:\"channel_id\"'
  _MSGCHANNELOPENACK.fields_by_name['counterparty_channel_id']._options = None
  _MSGCHANNELOPENACK.fields_by_name['counterparty_channel_id']._serialized_options = b'\362\336\037\036yaml:\"counterparty_channel_id\"'
  _MSGCHANNELOPENACK.fields_by_name['counterparty_version']._options = None
  _MSGCHANNELOPENACK.fields_by_name['counterparty_version']._serialized_options = b'\362\336\037\033yaml:\"counterparty_version\"'
  _MSGCHANNELOPENACK.fields_by_name['proof_try']._options = None
  _MSGCHANNELOPENACK.fields_by_name['proof_try']._serialized_options = b'\362\336\037\020yaml:\"proof_try\"'
  _MSGCHANNELOPENACK.fields_by_name['proof_height']._options = None
  _MSGCHANNELOPENACK.fields_by_name['proof_height']._serialized_options = b'\362\336\037\023yaml:\"proof_height\"\310\336\037\000'
  _MSGCHANNELOPENACK._options = None
  _MSGCHANNELOPENACK._serialized_options = b'\350\240\037\000\210\240\037\000'
  _MSGCHANNELOPENCONFIRM.fields_by_name['port_id']._options = None
  _MSGCHANNELOPENCONFIRM.fields_by_name['port_id']._serialized_options = b'\362\336\037\016yaml:\"port_id\"'
  _MSGCHANNELOPENCONFIRM.fields_by_name['channel_id']._options = None
  _MSGCHANNELOPENCONFIRM.fields_by_name['channel_id']._serialized_options = b'\362\336\037\021yaml:\"channel_id\"'
  _MSGCHANNELOPENCONFIRM.fields_by_name['proof_ack']._options = None
  _MSGCHANNELOPENCONFIRM.fields_by_name['proof_ack']._serialized_options = b'\362\336\037\020yaml:\"proof_ack\"'
  _MSGCHANNELOPENCONFIRM.fields_by_name['proof_height']._options = None
  _MSGCHANNELOPENCONFIRM.fields_by_name['proof_height']._serialized_options = b'\362\336\037\023yaml:\"proof_height\"\310\336\037\000'
  _MSGCHANNELOPENCONFIRM._options = None
  _MSGCHANNELOPENCONFIRM._serialized_options = b'\350\240\037\000\210\240\037\000'
  _MSGCHANNELCLOSEINIT.fields_by_name['port_id']._options = None
  _MSGCHANNELCLOSEINIT.fields_by_name['port_id']._serialized_options = b'\362\336\037\016yaml:\"port_id\"'
  _MSGCHANNELCLOSEINIT.fields_by_name['channel_id']._options = None
  _MSGCHANNELCLOSEINIT.fields_by_name['channel_id']._serialized_options = b'\362\336\037\021yaml:\"channel_id\"'
  _MSGCHANNELCLOSEINIT._options = None
  _MSGCHANNELCLOSEINIT._serialized_options = b'\350\240\037\000\210\240\037\000'
  _MSGCHANNELCLOSECONFIRM.fields_by_name['port_id']._options = None
  _MSGCHANNELCLOSECONFIRM.fields_by_name['port_id']._serialized_options = b'\362\336\037\016yaml:\"port_id\"'
  _MSGCHANNELCLOSECONFIRM.fields_by_name['channel_id']._options = None
  _MSGCHANNELCLOSECONFIRM.fields_by_name['channel_id']._serialized_options = b'\362\336\037\021yaml:\"channel_id\"'
  _MSGCHANNELCLOSECONFIRM.fields_by_name['proof_init']._options = None
  _MSGCHANNELCLOSECONFIRM.fields_by_name['proof_init']._serialized_options = b'\362\336\037\021yaml:\"proof_init\"'
  _MSGCHANNELCLOSECONFIRM.fields_by_name['proof_height']._options = None
  _MSGCHANNELCLOSECONFIRM.fields_by_name['proof_height']._serialized_options = b'\362\336\037\023yaml:\"proof_height\"\310\336\037\000'
  _MSGCHANNELCLOSECONFIRM._options = None
  _MSGCHANNELCLOSECONFIRM._serialized_options = b'\350\240\037\000\210\240\037\000'
  _MSGRECVPACKET.fields_by_name['packet']._options = None
  _MSGRECVPACKET.fields_by_name['packet']._serialized_options = b'\310\336\037\000'
  _MSGRECVPACKET.fields_by_name['proof_commitment']._options = None
  _MSGRECVPACKET.fields_by_name['proof_commitment']._serialized_options = b'\362\336\037\027yaml:\"proof_commitment\"'
  _MSGRECVPACKET.fields_by_name['proof_height']._options = None
  _MSGRECVPACKET.fields_by_name['proof_height']._serialized_options = b'\362\336\037\023yaml:\"proof_height\"\310\336\037\000'
  _MSGRECVPACKET._options = None
  _MSGRECVPACKET._serialized_options = b'\350\240\037\000\210\240\037\000'
  _MSGTIMEOUT.fields_by_name['packet']._options = None
  _MSGTIMEOUT.fields_by_name['packet']._serialized_options = b'\310\336\037\000'
  _MSGTIMEOUT.fields_by_name['proof_unreceived']._options = None
  _MSGTIMEOUT.fields_by_name['proof_unreceived']._serialized_options = b'\362\336\037\027yaml:\"proof_unreceived\"'
  _MSGTIMEOUT.fields_by_name['proof_height']._options = None
  _MSGTIMEOUT.fields_by_name['proof_height']._serialized_options = b'\362\336\037\023yaml:\"proof_height\"\310\336\037\000'
  _MSGTIMEOUT.fields_by_name['next_sequence_recv']._options = None
  _MSGTIMEOUT.fields_by_name['next_sequence_recv']._serialized_options = b'\362\336\037\031yaml:\"next_sequence_recv\"'
  _MSGTIMEOUT._options = None
  _MSGTIMEOUT._serialized_options = b'\350\240\037\000\210\240\037\000'
  _MSGTIMEOUTONCLOSE.fields_by_name['packet']._options = None
  _MSGTIMEOUTONCLOSE.fields_by_name['packet']._serialized_options = b'\310\336\037\000'
  _MSGTIMEOUTONCLOSE.fields_by_name['proof_unreceived']._options = None
  _MSGTIMEOUTONCLOSE.fields_by_name['proof_unreceived']._serialized_options = b'\362\336\037\027yaml:\"proof_unreceived\"'
  _MSGTIMEOUTONCLOSE.fields_by_name['proof_close']._options = None
  _MSGTIMEOUTONCLOSE.fields_by_name['proof_close']._serialized_options = b'\362\336\037\022yaml:\"proof_close\"'
  _MSGTIMEOUTONCLOSE.fields_by_name['proof_height']._options = None
  _MSGTIMEOUTONCLOSE.fields_by_name['proof_height']._serialized_options = b'\362\336\037\023yaml:\"proof_height\"\310\336\037\000'
  _MSGTIMEOUTONCLOSE.fields_by_name['next_sequence_recv']._options = None
  _MSGTIMEOUTONCLOSE.fields_by_name['next_sequence_recv']._serialized_options = b'\362\336\037\031yaml:\"next_sequence_recv\"'
  _MSGTIMEOUTONCLOSE._options = None
  _MSGTIMEOUTONCLOSE._serialized_options = b'\350\240\037\000\210\240\037\000'
  _MSGACKNOWLEDGEMENT.fields_by_name['packet']._options = None
  _MSGACKNOWLEDGEMENT.fields_by_name['packet']._serialized_options = b'\310\336\037\000'
  _MSGACKNOWLEDGEMENT.fields_by_name['proof_acked']._options = None
  _MSGACKNOWLEDGEMENT.fields_by_name['proof_acked']._serialized_options = b'\362\336\037\022yaml:\"proof_acked\"'
  _MSGACKNOWLEDGEMENT.fields_by_name['proof_height']._options = None
  _MSGACKNOWLEDGEMENT.fields_by_name['proof_height']._serialized_options = b'\362\336\037\023yaml:\"proof_height\"\310\336\037\000'
  _MSGACKNOWLEDGEMENT._options = None
  _MSGACKNOWLEDGEMENT._serialized_options = b'\350\240\037\000\210\240\037\000'
  _MSGCHANNELOPENINIT._serialized_start=144
  _MSGCHANNELOPENINIT._serialized_end=280
  _MSGCHANNELOPENINITRESPONSE._serialized_start=282
  _MSGCHANNELOPENINITRESPONSE._serialized_end=310
  _MSGCHANNELOPENTRY._serialized_start=313
  _MSGCHANNELOPENTRY._serialized_end=694
  _MSGCHANNELOPENTRYRESPONSE._serialized_start=696
  _MSGCHANNELOPENTRYRESPONSE._serialized_end=723
  _MSGCHANNELOPENACK._serialized_start=726
  _MSGCHANNELOPENACK._serialized_end=1103
  _MSGCHANNELOPENACKRESPONSE._serialized_start=1105
  _MSGCHANNELOPENACKRESPONSE._serialized_end=1132
  _MSGCHANNELOPENCONFIRM._serialized_start=1135
  _MSGCHANNELOPENCONFIRM._serialized_end=1384
  _MSGCHANNELOPENCONFIRMRESPONSE._serialized_start=1386
  _MSGCHANNELOPENCONFIRMRESPONSE._serialized_end=1417
  _MSGCHANNELCLOSEINIT._serialized_start=1419
  _MSGCHANNELCLOSEINIT._serialized_end=1546
  _MSGCHANNELCLOSEINITRESPONSE._serialized_start=1548
  _MSGCHANNELCLOSEINITRESPONSE._serialized_end=1577
  _MSGCHANNELCLOSECONFIRM._serialized_start=1580
  _MSGCHANNELCLOSECONFIRM._serialized_end=1832
  _MSGCHANNELCLOSECONFIRMRESPONSE._serialized_start=1834
  _MSGCHANNELCLOSECONFIRMRESPONSE._serialized_end=1866
  _MSGRECVPACKET._serialized_start=1869
  _MSGRECVPACKET._serialized_end=2095
  _MSGRECVPACKETRESPONSE._serialized_start=2097
  _MSGRECVPACKETRESPONSE._serialized_end=2120
  _MSGTIMEOUT._serialized_start=2123
  _MSGTIMEOUT._serialized_end=2405
  _MSGTIMEOUTRESPONSE._serialized_start=2407
  _MSGTIMEOUTRESPONSE._serialized_end=2427
  _MSGTIMEOUTONCLOSE._serialized_start=2430
  _MSGTIMEOUTONCLOSE._serialized_end=2764
  _MSGTIMEOUTONCLOSERESPONSE._serialized_start=2766
  _MSGTIMEOUTONCLOSERESPONSE._serialized_end=2793
  _MSGACKNOWLEDGEMENT._serialized_start=2796
  _MSGACKNOWLEDGEMENT._serialized_end=3042
  _MSGACKNOWLEDGEMENTRESPONSE._serialized_start=3044
  _MSGACKNOWLEDGEMENTRESPONSE._serialized_end=3072
  _MSG._serialized_start=3075
  _MSG._serialized_end=4146
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/insurance/v1beta1/tx.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from injective.oracle.v1beta1 import oracle_pb2 as injective_dot_oracle_dot_v1beta1_dot_oracle__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$injective/insurance/v1beta1/tx.proto\x12\x1binjective.insurance.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a%injective/oracle/v1beta1/oracle.proto\"\x87\x02\n\x16MsgCreateInsuranceFund\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x0e\n\x06ticker\x18\x02 \x01(\t\x12\x13\n\x0bquote_denom\x18\x03 \x01(\t\x12\x13\n\x0boracle_base\x18\x04 \x01(\t\x12\x14\n\x0coracle_quote\x18\x05 \x01(\t\x12\x39\n\x0boracle_type\x18\x06 \x01(\x0e\x32$.injective.oracle.v1beta1.OracleType\x12\x0e\n\x06\x65xpiry\x18\x07 \x01(\x03\x12\x38\n\x0finitial_deposit\x18\x08 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\" \n\x1eMsgCreateInsuranceFundResponse\"n\n\rMsgUnderwrite\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x11\n\tmarket_id\x18\x02 \x01(\t\x12\x30\n\x07\x64\x65posit\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x17\n\x15MsgUnderwriteResponse\"t\n\x14MsgRequestRedemption\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x11\n\tmarket_id\x18\x02 \x01(\t\x12/\n\x06\x61mount\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x1e\n\x1cMsgRequestRedemptionResponse2\x81\x03\n\x03Msg\x12\x87\x01\n\x13\x43reateInsuranceFund\x12\x33.injective.insurance.v1beta1.MsgCreateInsuranceFund\x1a;.injective.insurance.v1beta1.MsgCreateInsuranceFundResponse\x12l\n\nUnderwrite\x12*.injective.insurance.v1beta1.MsgUnderwrite\x1a\x32.injective.insurance.v1beta1.MsgUnderwriteResponse\x12\x81\x01\n\x11RequestRedemption\x12\x31.injective.insurance.v1beta1.MsgRequestRedemption\x1a\x39.injective.insurance.v1beta1.MsgRequestRedemptionResponseBQZOgithub.com/InjectiveLabs/injective-core/injective-chain/modules/insurance/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.insurance.v1beta1.tx_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZOgithub.com/InjectiveLabs/injective-core/injective-chain/modules/insurance/types'
  _MSGCREATEINSURANCEFUND.fields_by_name['initial_deposit']._options = None
  _MSGCREATEINSURANCEFUND.fields_by_name['initial_deposit']._serialized_options = b'\310\336\037\000'
  _MSGCREATEINSURANCEFUND._options = None
  _MSGCREATEINSURANCEFUND._serialized_options = b'\350\240\037\000\210\240\037\000'
  _MSGUNDERWRITE.fields_by_name['deposit']._options = None
  _MSGUNDERWRITE.fields_by_name['deposit']._serialized_options = b'\310\336\037\000'
  _MSGUNDERWRITE._options = None
  _MSGUNDERWRITE._serialized_options = b'\350\240\037\000\210\240\037\000'
  _MSGREQUESTREDEMPTION.fields_by_name['amount']._options = None
  _MSGREQUESTREDEMPTION.fields_by_name['amount']._serialized_options = b'\310\336\037\000'
  _MSGREQUESTREDEMPTION._options = None
  _MSGREQUESTREDEMPTION._serialized_options = b'\350\240\037\000\210\240\037\000'
  _MSGCREATEINSURANCEFUND._serialized_start=163
  _MSGCREATEINSURANCEFUND._serialized_end=426
  _MSGCREATEINSURANCEFUNDRESPONSE._serialized_start=428
  _MSGCREATEINSURANCEFUNDRESPONSE._serialized_end=460
  _MSGUNDERWRITE._serialized_start=462
  _MSGUNDERWRITE._serialized_end=572
  _MSGUNDERWRITERESPONSE._serialized_start=574
  _MSGUNDERWRITERESPONSE._serialized_end=597
  _MSGREQUESTREDEMPTION._serialized_start=599
  _MSGREQUESTREDEMPTION._serialized_end=715
  _MSGREQUESTREDEMPTIONRESPONSE._serialized_start=717
  _MSGREQUESTREDEMPTIONRESPONSE._serialized_end=747
  _MSG._serialized_start=750
  _MSG._serialized_end=1135
# @@protoc_insertion_point(module_scope)
